@@ -58,6 +58,13 @@ name_cache = {}
 remark_about_missing_module_info = set()
 
 
+def module_or_string(module):
+    if isinstance(module, str):
+        return module
+    if isinstance(module, Module):
+        return module.name
+
+
 class NotInAddonsPath(Exception):
     pass
 
@@ -784,7 +791,7 @@ class Modules(object):
                 if dep == "base":
                     data[mod.name][dep] = {}
                     continue
-                dep_mod = [x for x in modules if x.name == dep]
+                dep_mod = [x for x in modules if module_or_string(x) == dep]
                 try:
                     dep_mod = dep_mod[0]
                 except IndexError:
@@ -1132,7 +1139,7 @@ class Module(object):
     def _get_by_name(cls, name):
         try:
             res = ModulesCache.get(name)
-        except IndexError:
+        except (IndexError, KeyError):
             pass
         else:
             return res
@@ -1163,7 +1170,7 @@ class Module(object):
         for path in get_odoo_addons_paths():
             if (path / name).resolve().is_dir():
                 return Module(path / name)
-        raise Exception("Module not found or not linked: {}".format(name))
+        raise KeyError(f"Module not found or not linked: {name}")
 
     @property
     def dependent_modules(self):
@@ -1479,7 +1486,8 @@ def _determine_affected_modules_for_ir_field_and_related(config, fieldname, mode
         name = f"field_{model.replace('.', '_')}__{fieldname}"
         sql = f"select module from ir_model_data where model='ir.model.fields' and name='{name}'"
         ir_model_data = _execute_sql(conn, sql, fetchone=True)
-        return ir_model_data[0]
+        if ir_model_data:
+            return ir_model_data[0]
 
     sql = f"select id, model, related from ir_model_fields where related like '%.{fieldname}'"
     related_fields = _execute_sql(conn, sql, fetchall=True)
@@ -1492,5 +1500,7 @@ def _determine_affected_modules_for_ir_field_and_related(config, fieldname, mode
             affected_modules.append(
                 _get_model_for_field(resolved_model, resolved_fieldname)
             )
-    affected_modules.append(_get_model_for_field(modelname, fieldname))
+    module_of_field = _get_model_for_field(modelname, fieldname)
+    if module_of_field:
+        affected_modules.append(module_of_field)
     return affected_modules
